Aggregate reading object (sarpy.io.complex.aggregate)
=====================================================

.. automodule:: sarpy.io.complex.aggregate
    :members:
    :show-inheritance:
    :inherited-members:
